==> emoji-mart-virtualized-3.0.17.tgz: package/dist-es/components/category.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _this = this;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import NimbleEmoji from './emoji/nimble-emoji';
export default (function (_ref) {
  var i18n = _ref.i18n,
      _ref$perLine = _ref.perLine,
      perLine = _ref$perLine === void 0 ? 9 : _ref$perLine,
      _ref$emojis = _ref.emojis,
      emojis = _ref$emojis === void 0 ? [] : _ref$emojis,
      _ref$hasStickyPositio = _ref.hasStickyPosition,
      hasStickyPosition = _ref$hasStickyPositio === void 0 ? false : _ref$hasStickyPositio,
      emojiProps = _ref.emojiProps,
      data = _ref.data;
  console.log("DDDDD", emojis);
  return function (_ref2) {
    var style = _ref2.style,
        rowIndex = _ref2.rowIndex,
        columnIndex = _ref2.columnIndex;
    var emoji = emojis[perLine * rowIndex + columnIndex] || null;
    if (!emoji) return null;

    var renderLabel = function renderLabel() {
      if (!emoji.cat_id) return null;
      var label = i18n.categories[id] || emoji.cat_name;
      var labelStyles = {},
          labelSpanStyles = {}; // if (!emojis) {
      //   containerStyles = {
      //     display: 'none',
      //   }
      // }

      if (!hasStickyPosition) {
        labelStyles = {
          height: 28
        };
        labelSpanStyles = {
          position: 'absolute'
        };
      }

      return React.createElement("div", {
        style: labelStyles,
        "data-name": label,
        className: "emoji-mart-category-label"
      }, React.createElement("span", {
        style: labelSpanStyles,
        ref: _this.setLabelRef,
        "aria-hidden": true
        /* already labeled by the section aria-label */

      }, label));
    };

    return React.createElement(React.Fragment, null, renderLabel(), React.createElement("li", {
      style: style,
      key: emoji.short_names && emoji.short_names.join('_') || emoji
    }, NimbleEmoji(_objectSpread({
      emoji: emoji,
      data: data
    }, emojiProps))));
  };
});

==> emoji-mart-virtualized-3.0.20.tgz: package/dist-es/components/category.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _this = this;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import NimbleEmoji from './emoji/nimble-emoji';
export default (function (_ref) {
  var i18n = _ref.i18n,
      _ref$perLine = _ref.perLine,
      perLine = _ref$perLine === void 0 ? 9 : _ref$perLine,
      _ref$emojis = _ref.emojis,
      emojis = _ref$emojis === void 0 ? [] : _ref$emojis,
      _ref$hasStickyPositio = _ref.hasStickyPosition,
      hasStickyPosition = _ref$hasStickyPositio === void 0 ? false : _ref$hasStickyPositio,
      emojiProps = _ref.emojiProps,
      data = _ref.data;
  console.log("DDDDD", emojis, "perLine", perLine);

  var Emoji = function Emoji(_ref2) {
    var style = _ref2.style,
        rowIndex = _ref2.rowIndex,
        columnIndex = _ref2.columnIndex;
    var emoji = emojis[perLine * rowIndex + columnIndex] || null;
    if (!emoji) return null;

    var renderLabel = function renderLabel() {
      if (!emoji.cat_id) return null;
      var label = i18n.categories[emoji.cat_id] || emoji.cat_name;
      var labelStyles = {},
          labelSpanStyles = {}; // if (!emojis) {
      //   containerStyles = {
      //     display: 'none',
      //   }
      // }

      if (!hasStickyPosition) {
        labelStyles = {
          height: 28
        };
        labelSpanStyles = {
          position: 'absolute'
        };
      }

      return React.createElement("div", {
        style: labelStyles,
        "data-name": label,
        className: "emoji-mart-category-label"
      }, React.createElement("span", {
        style: labelSpanStyles,
        ref: _this.setLabelRef,
        "aria-hidden": true
        /* already labeled by the section aria-label */

      }, label));
    };

    return React.createElement(React.Fragment, null, renderLabel(), React.createElement("li", {
      style: style,
      key: emoji.short_names && emoji.short_names.join('_') || emoji
    }, NimbleEmoji(_objectSpread({
      emoji: emoji,
      data: data
    }, emojiProps))));
  };

  return Emoji;
});
